@@ -9,6 +9,8 @@ The problem with SIP is that all inter-module depedencies (for example from
 PyQt4.Qt to PyQt4.QtCore) are handled in C code and therefore cannot be
 detected by the python code in py2app).
 """
+from __future__ import absolute_import
+
 import glob
 import os
 import sys
@@ -50,6 +52,7 @@ class Sip(object):
             raise ImportError
 
         # Qt is GHETTO!
+        # This looks wrong, setting DYLD_LIBRARY_PATH should not be needed!
         dyld_library_path = os.environ.get("DYLD_LIBRARY_PATH", "").split(":")
 
         if qtdir not in dyld_library_path:
